package
Version:
v0.0.0-...-e3601d1
Opens a new window with list of versions in this module.
Published: Dec 7, 2025
License: MulanPSL-2.0
Opens a new window with license information.
Imports: 2
Opens a new window with list of imports.
Imported by: 15
Opens a new window with list of known importers.
Documentation
¶
func Debug(ps ...interface{})
func Error(ps ...interface{})
func Info(ps ...interface{})
func Log(ps ...interface{})
Source Files
¶
Click to show internal directories.
Click to hide internal directories.